@@ -64,3 +64,19 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.getOidByShopIds", {"shopIds": shop_ids})
 
+    def update_busy_level_setting(self, shop_id, week_setting, date_setting):
+        """
+        更新店铺营业时间预设置
+        :param shopId:店铺 id 
+        :param weekSetting:一周营业时间预设置, 参考 OShopBusyLevelSetting weekSetting 字段定义 
+        :param dateSetting:特定日期营业时间预设置, 参考 OShopBusyLevelSetting dateSetting 字段定义 
+        """
+        return self.__client.call("eleme.shop.updateBusyLevelSetting", {"shopId": shop_id, "weekSetting": week_setting, "dateSetting": date_setting})
+
+    def get_busy_level_setting(self, shop_id):
+        """
+        获取店铺营业时间预设置
+        :param shopId:店铺 id 
+        """
+        return self.__client.call("eleme.shop.getBusyLevelSetting", {"shopId": shop_id})
+
